diff src/util.h @ 7675:66d9440db6ec

[gaim-migrate @ 8319] marv writes: "This fixes some crashes on unusual long profile fields for yahoo, and probably msn. One test case is the yahoo [l]user "kent_nwo4life", which crashes without this patch." committer: Tailor Script <tailor@pidgin.im>
author Luke Schierer <lschiere@pidgin.im>
date Sun, 30 Nov 2003 23:49:45 +0000
parents 42e5d2f4e4b1
children 1363f91da9cc
line wrap: on
line diff
--- a/src/util.h	Sun Nov 30 20:33:38 2003 +0000
+++ b/src/util.h	Sun Nov 30 23:49:45 2003 +0000
@@ -174,7 +174,8 @@
  * protocols/yahoo/yahoo.c for example usage.
  *
  * @param str            The string to parse.
  * @param dest_buffer    The destination buffer to append the new
  *                       field info to.
  * @param start_token    The beginning token.
  * @param skip           The number of characters to skip after the
@@ -188,14 +189,12 @@
  *
  * @return TRUE if successful, or FALSE otherwise.
  */
-gboolean gaim_markup_extract_info_field(const char *str, char *dest_buffer,
-										const char *start_token, int skip,
-										const char *end_token,
-										char check_value,
-										const char *no_value_token,
-										const char *display_name,
-										gboolean is_link,
-										const char *link_prefix);
+gboolean gaim_markup_extract_info_field(const char *str, int len, GString *dest,
+                                        const char *start_token, int skip,
+                                        const char *end_token, char check_value,
+                                        const char *no_value_token,
+                                        const char *display_name, gboolean is_link,
+                                        const char *link_prefix);
 
 /**
  * Converts HTML markup to XHTML.
@@ -174,7 +174,8 @@
  *
  * @param str            The string to parse.
- * @param dest_buffer    The destination buffer to append the new
+ * @param len            The size of str.
+ * @param dest           The destination GString to append the new
  *                       field info to.
  * @param start_token    The beginning token.